@@ -49,7 +49,8 @@ class CapellaConsoleClient:
 
     Note:
 
-    * provide either email and password or a valid jwt token for authentication
+    * not providing either email and password or a jwt token for authentication
+      will prompt you for email and password, which is not what you want in a script
 
     NOTE: Precedence order (high to low)
         1. email and password
@@ -65,7 +66,6 @@ class CapellaConsoleClient:
         no_token_check: bool = False,
         base_url: Optional[str] = CONSOLE_API_URL,
     ):
-
         self.verbose = verbose
         logger.setLevel(logging.WARNING)
         if verbose:
@@ -198,7 +198,7 @@ class CapellaConsoleClient:
         self,
         stac_ids: Optional[List[str]] = None,
         items: Optional[List[Dict[str, Any]]] = None,
-    ) -> None:
+    ) -> Dict[str, Any]:
         stac_ids = _validate_stac_id_or_stac_items(stac_ids, items)
 
         logger.info(f"reviewing order for {', '.join(stac_ids)}")
@@ -221,6 +221,7 @@ class CapellaConsoleClient:
             raise InsufficientFundsError(
                 review_order_response["authorizationDenialReason"]["message"]
             )
+        return review_order_response
 
     def submit_order(
         self,
@@ -409,7 +410,7 @@ class CapellaConsoleClient:
         include: Union[List[str], str] = None,
         exclude: Union[List[str], str] = None,
         override: bool = False,
-        threaded: bool = False,
+        threaded: bool = True,
         show_progress: bool = False,
         separate_dirs: bool = True,
     ) -> Dict[str, Dict[str, Path]]:
@@ -496,6 +497,10 @@ class CapellaConsoleClient:
             }
             download_requests.extend(cur_download_requests)
 
+        if not download_requests:
+            logger.warning("Nothing to download")
+            return by_stac_id  # type: ignore
+
         # download
         _perform_download(
             download_requests=download_requests,
@@ -554,7 +559,7 @@ class CapellaConsoleClient:
         include: Union[List[str], str] = None,
         exclude: Union[List[str], str] = None,
         override: bool = False,
-        threaded: bool = False,
+        threaded: bool = True,
         show_progress: bool = False,
     ) -> Dict[str, Path]:
         """
@@ -602,6 +607,10 @@ class CapellaConsoleClient:
 
         download_requests = _gather_download_requests(assets_presigned, local_dir, include, exclude)  # type: ignore
 
+        if not download_requests:
+            logger.warning("Nothing to download")
+            return {}
+
         return _perform_download(
             download_requests=download_requests,
             override=override,
